package org.churchsw.scripture.plugins;

import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.IOException;
import java.util.Iterator;
import java.util.Properties;
import java.util.Set;

import javax.swing.JOptionPane;

public class ModernEnglish extends PluginClass {

	Properties modern=new Properties();
	
	public ModernEnglish() {

		int c = JOptionPane
				.showConfirmDialog(
						null,
						"This plugin will convert old English like Thou,Thee,Thy,Thine,Ye to You,Your.\n"
								+ "[Note: You can add your own rules to change to modern language using property\n"
								+ "file: modern.prop. But you will lose some critical information which is present\n"
								+ "in old English. Use this filter with caution!]\n\n"
								+ "Are you sure you want to proceed?",
						"Old English to Modern English",
						JOptionPane.YES_NO_OPTION);
		if (c == JOptionPane.YES_OPTION) {	
			try {
				modern.load(new FileInputStream("modern.prop"));
			} catch (FileNotFoundException e) {
				JOptionPane.showMessageDialog(null, "Error:"+e.getLocalizedMessage());
				return;
			} catch (IOException e) {
				JOptionPane.showMessageDialog(null, "Error:"+e.getLocalizedMessage());
				return;
			}
			
			convertOldToModernEnglish();
			convertSequence();
			removeDuplicates();
			reloadBibleChapter(true);
		}
	}
	
	
	private void convertOldToModernEnglish() {
		Properties words = getDictionary();
		Set set = words.keySet();
		Iterator i = set.iterator();
		Properties mwords = new Properties();
		while (i.hasNext()) {
			String key = (String) i.next();
			String val = words.getProperty(key);
			String[] vals = val.split("[,]");
			StringBuffer sb = new StringBuffer();
			for (int j = 0; j < vals.length; j++) {
				if (sb.toString().toLowerCase().indexOf(
						vals[j].toLowerCase()) != -1)
					continue;
				
				String newval=modern.getProperty(vals[j]);
				if(newval==null)
					newval=modern.getProperty(vals[j].toLowerCase());
				if(newval==null)
					newval=modern.getProperty(vals[j].toUpperCase());
				
				if (!sb.toString().trim().equalsIgnoreCase(""))
					sb.append(",");
				if(newval==null)
					sb.append(vals[j]);
				else
					sb.append(newval);
			}
			mwords.setProperty(key, sb.toString());
		}
		setDictionary(mwords);		
	}


	private void convertSequence() {
		Properties words = getSequence();
		Set set = words.keySet();
		Iterator i = set.iterator();
		Properties mwords = new Properties();
		while (i.hasNext()) {
			String key = (String) i.next();
			String val = words.getProperty(key);
			String[] vals = val.split("[ ]");
			StringBuffer sb = new StringBuffer();
			for (int j = 0; j < vals.length; j++) {
				if (sb.toString().toLowerCase().indexOf(
						vals[j].toLowerCase()) != -1)
					continue;
				
				String newval=modern.getProperty(vals[j]);
				if(newval==null)
					newval=modern.getProperty(vals[j].toLowerCase());
				if(newval==null)
					newval=modern.getProperty(vals[j].toUpperCase());
				
				if (!sb.toString().trim().equalsIgnoreCase(""))
					sb.append(" ");
				if(newval==null)
					sb.append(vals[j]);
				else
					sb.append(newval);
			}
			mwords.setProperty(key, sb.toString().trim());
		}
		setSequence(mwords);		
	}
	
	private void removeDuplicates()
	{
		Properties words = getDictionary();
		Set set = words.keySet();
		Iterator i = set.iterator();
		Properties mwords = new Properties();
		while (i.hasNext()) {
			String key = (String) i.next();
			String val = words.getProperty(key);
			String[] vals = val.split("[,]");
			StringBuffer sb = new StringBuffer();
			for (int j = 0; j < vals.length; j++) {
				if (sb.toString().toLowerCase().indexOf(
						vals[j].toLowerCase()) != -1)
					continue;
				if (!sb.toString().trim().equalsIgnoreCase(""))
					sb.append(",");
				sb.append(vals[j]);
			}
			mwords.setProperty(key, sb.toString());
		}
		setDictionary(mwords);
	}
}
